:mod:`nolearn.dataset`
----------------------

.. warning::

   The nolearn.dataset module will be removed in nolearn 0.6.  If you
   want to continue to use this module, please consider copying the
   code into your own project.

.. automodule:: nolearn.dataset
